Summary: Execution Environment Service for the ARGUS framework
Name: ees
Version: 0.2.1
Release: 1%{?dist}
Vendor: Nikhef
License: ASL 2.0
Group: System Environment/Daemons
URL: http://wiki.nikhef.nl/grid/EES
Source0: http://software.nikhef.nl/security/%{name}/%{name}-%{version}.tar.gz
# BuildRoot is still required for EPEL5
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires: bison, flex
BuildRequires: xacml-devel
BuildRequires: gsoap-devel
# Use xacml 1.4.3 for ID/issuer API, also get server timeouts API
Requires: xacml%{?_isa} >= 1.4.3
Requires: logrotate
Requires(post): chkconfig
Requires(preun): initscripts, chkconfig
Requires(postun): initscripts

%description

The EES is a service that can procure execution environments on Grid
sites. These execution environments can be as simple as an existing
Unix user account to which the supplied user credentials are mapped
or as complex as deploying full virtual machines for a user. 

The role of the EES is to ensure that an appropriate site-specific
execution environment is procured based on the site-agnostic
obligations and attributes it receives as input in the form of
SAML2-XACML2 requests. It responds to requests from the Policy
Decision Point (PDP), but can also act as a standalone service.

%package devel
Summary: Execution Environment Service development files
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel

This package contains the header files and development libraries
of the ees package.

%prep
%setup -q

%build

%configure --disable-static --disable-rpath

# The following lines were suggested by
# https://fedoraproject.org/wiki/Packaging/Guidelines to prevent any
# RPATHs creeping in, and by
# https://fedoraproject.org/wiki/Common_Rpmlint_issues#unused-direct-shlib-dependency
# to prevent unnecessary linking
%define fixlibtool() sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool\
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool\
sed -i -e 's! -shared ! -Wl,--as-needed\\0!g' libtool

# Remove Default-Start line from init script: Debian demands it but Fedora
# doesn't want it
sed -i '/^# Default-Start: .*$/d' setup/init/ees

%fixlibtool
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

# Remove example plugin
rm -f $RPM_BUILD_ROOT/%{_libdir}/ees/*ees_example_plugin.*

%clean
rm -rf $RPM_BUILD_ROOT

# Add the ees user (see http://fedoraproject.org/wiki/Packaging:UsersAndGroups)
%pre
getent group ees >/dev/null || groupadd -r ees
getent passwd ees >/dev/null || \
    useradd -r -g ees -d / -s /sbin/nologin \
    -c "ees user account to be used with %{_sbindir}/ees" ees
exit 0

%post
/sbin/ldconfig
/sbin/chkconfig --add ees

%preun
if [ $1 -eq 0 ] ; then
    /sbin/service ees stop >/dev/null 2>&1
    /sbin/chkconfig --del ees
fi

%postun
/sbin/ldconfig
if [ "$1" -ge "1" ] ; then
    /sbin/service ees condrestart >/dev/null 2>&1 || :
fi



%files
%doc LICENSE AUTHORS BUGS NEWS README
# Create ees config file owned by ees group such that ees can read it. Others
# should not be able as it might contain passwords.
%attr(640, root, ees) %config(noreplace) %{_sysconfdir}/ees.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/ees
%{_sysconfdir}/init.d/ees
%{_sbindir}/ees
%{_libdir}/libeef.so.*
%{_libdir}/libeics.so.*
%{_mandir}/man1/ees.1*
%{_mandir}/man5/ees.conf.5*
# Add plugin dir
%dir %{_libdir}/ees
# Next three lines are for the basic EES plugins
%{_libdir}/ees/*.mod
%{_libdir}/ees/*.so
%{_mandir}/man8/*.mod.8*

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/eef
%dir %{_includedir}/eics
%{_includedir}/eef/*
%{_includedir}/eics/*
%{_libdir}/libeef.so
%{_libdir}/libeics.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Aug 22 2014 Mischa Salle <msalle@nikhef.nl> 0.2.1-1
- Add EICS include files
- Remove all example plugin files
- Init script creates pidfile and logfile dirs, don't create them here
- Fedora does not like Default-Start
- Update version

* Tue Jul 15 2014 Mischa Salle <msalle@nikhef.nl> 0.2.0-2
- Create pidfile directory
- Install LICENSE instead of COPYING, install BUGS
- Add plugin manpages
- Add fixes for RPATHS and unneeded libraries
- Add arch suffix for requires
- Remove unneeded default root attr
- Add .pc files to -devel
- Add minimum version for xacml
- Update version

* Fri Oct 25 2012 Mischa Salle <msalle@nikhef.nl> 0.1.4-1
- Only add non-plugin .so files to devel package.
- Add logrotate script, including requires.
- Add appropriate post, preun and postun section to enable and disable the
  service.
- Do not install the INSTALL file.
- Update URL.
- Update version.

* Mon Mar 26 2012 Mischa Salle <msalle@nikhef.nl> 0.1.3-1
- Create config file with specific permissions and ownership 
- Add noreplace flag to config file
- Create log directory %%{_localstatedir}/ees
- Add EES user and group
- Put Build dependency on xacml-devel instead of saml2-xacml2-c-lib-devel
- Bumped version

* Thu Mar  1 2012 Mischa Salle <msalle@nikhef.nl> 0.1.2-1
- Bumped version

* Mon Jan 30 2012 Mischa Salle <msalle@nikhef.nl> 0.1.1-1
- Bumped version

* Fri Dec 16 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.1.0
- Update build dependency on xacml

* Fri Dec 16 2011 Mischa Salle <msalle@nikhef.nl> 0.1.0-1
- Bumped version

* Tue Aug 23 2011 Mischa Salle <msalle@nikhef.nl> 0.0.10-4
- removed commented-out files
- Bumped version

* Tue Aug 23 2011 Mischa Salle <msalle@nikhef.nl> 0.0.10-3
- no longer needed to move init.d script
- Bumped version

* Mon Mar  7 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.3-1
- Bumped version
- disable rpath

* Fri Mar  4 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.2-2
- fixed license string
- disable static libraries
- added post(-un) scripts

* Thu Mar  3 2011 Dennis van Dok <dennisvd@nikhef.nl> 0.0.2-1
- Bumped version number

* Fri Feb 25 2011 Dennis van Dok <dennisvd@nikhef.nl> 
- Initial build.


